import * as React from 'react';
import Request from '../utils/request';
export type ProjectRecordProps = {
	name: string;
	id: number;
};
/**
 * @description 工程列表
 * @param options
 */
export const useProjectsList = () => {
	const [state, setState] = React.useState<{
		loading: boolean;
		dataSource: ProjectRecordProps[];
		total: number;
		page: number;
	}>({
		loading: false,
		dataSource: [],
		total: 0,
		page: 1,
	});
	const request = (params: {
		page: number;
		filter: string;
		page_size?: number;
	}) => {
		setState((preState) => ({ ...preState, loading: true }));
		return Request.sendRequest({
			url: '/v1/project/list',
			params,
		})
			.then((data: any) => {
				setState((preState) => ({
					...preState,
					...data,
					loading: false,
					dataSource: data.list,
				}));
			})
			.finally(() => {
				setState((preState) => ({ ...preState, loading: false }));
			});
	};
	return [state, request] as const;
};
/**
 * @description 获取项目详情
 */
export const useProjectDetail = () => {
	const [state, setState] = React.useState({
		loading: false,
		dataSource: {},
	});
	const request = (params: { id: number }) => {
		setState((preState) => ({ ...preState, loading: true }));
		return Request.sendRequest({
			url: `/v1/project/info/${params.id}`,
			params,
		})
			.then((data: any) => {
				setState((preState) => ({
					...preState,
					dataSource: {
						...data.info,
						project_plan: data.info.project_plan
							? JSON.parse(data.info.project_plan)
							: [],
						project_effect_pic: data.info.project_effect_pic
							? JSON.parse(data.info.project_effect_pic)
							: [],
					},
					loading: false,
				}));
			})
			.finally(() => {
				setState((preState) => ({ ...preState, loading: false }));
			});
	};

	return [state, request] as const;
};

export type projectFormProps = {
	name: string;
	desc: string;
	project_type: string;
	price: number;
	covered_area: number;
	project_function: string;
	total_level: number;
	building_storey?: string;
	project_leader: string;
	phone: string;
	construction: string;
	development: string;
	oversee: string;
	design: string;
	exploration: string;
	lon: number;
	lat: number;
	location: string;
	end_day: number;
	start_day: number;
};

/**
 * @description 新增项目
 */
export const useInsertProject = () => {
	const [state, setState] = React.useState({
		loading: false,
		dataSource: [],
	});
	const request = (data: projectFormProps) => {
		setState((preState) => ({ ...preState, loading: true }));
		return Request.sendRequest({
			url: '/v1/project',
			method: 'POST',
			data,
		}).finally(() => {
			setState((preState) => ({ ...preState, loading: false }));
		});
	};
	return [state, request] as const;
};

/**
 * @description 更新项目
 */
export const useProjectUpdate = () => {
	const [state, setState] = React.useState({
		loading: false,
		dataSource: [],
	});
	const request = (data: projectFormProps & { id: number }) => {
		setState((preState) => ({ ...preState, loading: true }));
		return Request.sendRequest({
			url: '/v1/project',
			method: 'PUT',
			data,
		}).finally(() => {
			setState((preState) => ({ ...preState, loading: false }));
		});
	};
	return [state, request] as const;
};
/**
 * @description 删除项目
 */
export const useDeleteProject = () => {
	const [state, setState] = React.useState({
		loading: false,
	});
	const request = (params: { id: number }) => {
		setState((preState) => ({ ...preState, loading: true }));
		return Request.sendRequest({
			url: `/v1/project/${params.id}`,
			method: 'DELETE',
		}).finally(() => {
			setState((preState) => ({ ...preState, loading: false }));
		});
	};
	return [state, request] as const;
};

/**
 * @description 获取项目限制区域
 */
export const useGetProjectLimitArea = () => {
	const [state, setState] = React.useState({
		loading: false,
		dataSource: {
			area_code: null,
			city_code: null,
		},
	});
	const request = () => {
		setState((preState) => ({ ...preState, loading: true }));
		return Request.sendRequest({
			url: `/v1/area_code_limit`,
		})
			.then((data: any) => {
				return { area_code: data.area_code, city_code: data.city_code };
			})
			.finally(() => {
				setState((preState) => ({ ...preState, loading: false }));
			});
	};
	return { state, request } as const;
};
